@@ -339,6 +339,7 @@ Main::Main(QCanvas& c, QWidget* parent, const char* name, WFlags f) :
     edit->insertItem("Add &Circle", this, SLOT(addCircle()), CTRL+Key_C);
     edit->insertItem("Add &Hexagon", this, SLOT(addHexagon()), CTRL+Key_H);
     edit->insertItem("Add &Polygon", this, SLOT(addPolygon()), CTRL+Key_P);
+    edit->insertItem("Add &Text", this, SLOT(addText()), CTRL+Key_T);
     edit->insertItem("Add &Line", this, SLOT(addLine()), CTRL+Key_L);
     edit->insertItem("Add &Rectangle", this, SLOT(addRectangle()), CTRL+Key_R);
     edit->insertItem("Add &Sprite", this, SLOT(addSprite()), CTRL+Key_S);
@@ -521,6 +522,15 @@ void Main::addPolygon()
     i->show();
 }
 
+void Main::addText()
+{
+    QCanvasText* i = new QCanvasText(&canvas);
+    i->setText("QCanvasText");
+    i->move(rand()%canvas.width(),rand()%canvas.height());
+    i->setZ(rand()%256);
+    i->show();
+}
+
 void Main::addLine()
 {
     QCanvasLine* i = new QCanvasLine(&canvas);
