@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/src/opengl/qgl_x11.cpp   2.2.1   edited 2000-08-25 $
+** $Id: qt/src/opengl/qgl_x11.cpp   2.2.2   edited 2000-11-03 $
 **
 ** Implementation of OpenGL classes for Qt
 **
@@ -116,11 +116,11 @@ static Colormap choose_cmap( Display *dpy, XVisualInfo *vi )
     XStandardColormap *c;
     int n, i;
 
-    //debug( "Choosing cmap for vID %0x", vi->visualid );
+    //qDebug( "Choosing cmap for vID %0x", vi->visualid );
 
     if ( vi->visualid == 
 	 XVisualIDFromVisual( (Visual*)QPaintDevice::x11AppVisual() ) ) {
-	//debug( "Using x11AppColormap" );
+	//qDebug( "Using x11AppColormap" );
 	return QPaintDevice::x11AppColormap();
     }
 
@@ -134,7 +134,7 @@ static Colormap choose_cmap( Display *dpy, XVisualInfo *vi )
 		    if ( c[i].visualid == vi->visual->visualid ) {
 			x->cmap = c[i].colormap;
 			x->scmap = c[i];
-			//debug( "Using HP_RGB scmap" );
+			//qDebug( "Using HP_RGB scmap" );
 
 		    }
 		    i++;
@@ -154,7 +154,7 @@ static Colormap choose_cmap( Display *dpy, XVisualInfo *vi )
 		    if ( c[i].visualid == vi->visualid ) {
 			x->cmap = c[i].colormap;
 			x->scmap = c[i];
-			//debug( "Using RGB_DEFAULT scmap" );
+			//qDebug( "Using RGB_DEFAULT scmap" );
 
 		    }
 		    i++;
@@ -168,7 +168,7 @@ static Colormap choose_cmap( Display *dpy, XVisualInfo *vi )
 	x->cmap = XCreateColormap( dpy, RootWindow(dpy,vi->screen), vi->visual,
 				   AllocNone );
 	x->alloc = TRUE;
-	//debug( "Allocating cmap" );
+	//qDebug( "Allocating cmap" );
 
     }
 
@@ -331,7 +331,7 @@ bool QGLContext::chooseContext( const QGLContext* shareContext )
 	return FALSE;
     glFormat.setDirectRendering( glXIsDirect( disp, (GLXContext)cx ) );
     if ( deviceIsPixmap() ) {
-#ifdef GLX_MESA_pixmap_colormap
+#if defined(GLX_MESA_pixmap_colormap) && defined(QGL_USE_MESA_EXT)
 	gpm = glXCreateGLXPixmapMESA( disp, (XVisualInfo *)vi,
 				      paintDevice->handle(),
 				      choose_cmap( disp, (XVisualInfo *)vi ) );
@@ -539,7 +539,7 @@ void QGLContext::makeCurrent()
 			     ((QWidget *)paintDevice)->winId(),
 			     (GLXContext)cx );
 #if defined(CHECK_NULL)
-    //    debug("makeCurrent: %i, vi=%i, vi->vi=%i, vi->id=%i", (int)this, (int)vi, (int)((XVisualInfo*)vi)->visual, (int)((XVisualInfo*)vi)->visualid );
+    //    qDebug("makeCurrent: %i, vi=%i, vi->vi=%i, vi->id=%i", (int)this, (int)vi, (int)((XVisualInfo*)vi)->visual, (int)((XVisualInfo*)vi)->visualid );
     if ( !ok )
 	qWarning("QGLContext::makeCurrent(): Failed.");
 #endif
@@ -867,7 +867,7 @@ void QGLWidget::setContext( QGLContext *context,
 	cmw[0] = w;
     }
 
-#if defined(GLX_MESA_release_buffers)
+#if defined(GLX_MESA_release_buffers) && defined(QGL_USE_MESA_EXT)
     if ( oldcx && oldcx->windowCreated() )
 	glXReleaseBuffersMESA( x11Display(), winId() );
 #endif
@@ -894,7 +894,7 @@ bool QGLWidget::renderCxPm( QPixmap* pm )
 	return FALSE;
 
     GLXPixmap glPm;
-#ifdef GLX_MESA_pixmap_colormap
+#if defined(GLX_MESA_pixmap_colormap) && defined(QGL_USE_MESA_EXT)
     glPm = glXCreateGLXPixmapMESA( x11Display(),
 				   (XVisualInfo*)glcx->vi,
 				   (Pixmap)pm->handle(),
