@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/src/tools/qtextstream.cpp   2.2.1   edited 2000-09-19 $
+** $Id: qt/src/tools/qtextstream.cpp   2.2.2   edited 2000-10-25 $
 **
 ** Implementation of QTextStream class
 **
@@ -193,10 +193,14 @@ const int QTextStream::floatfield  = ( QTextStream::scientific |
 
 class QTextStreamPrivate {
 public:
-    QTextStreamPrivate(): decoder( 0 ), sourceType( NotSet ) {}
+#ifndef QT_NO_TEXTCODEC
+    QTextStreamPrivate() : decoder( 0 ), sourceType( NotSet ) {}
     ~QTextStreamPrivate() { delete decoder; }
-
     QTextDecoder *decoder;		//???
+#else
+    QTextStreamPrivate() : sourceType( NotSet ) {}
+    ~QTextStreamPrivate() { }
+#endif
     QString ungetcBuf;
 
     enum SourceType { NotSet, IODevice, String, ByteArray, File };
@@ -664,6 +668,7 @@ uint QTextStream::ts_getbuf( QChar* buf, uint len )
 	}
     }
 
+#ifndef QT_NO_TEXTCODEC
     if ( mapper ) {
 	bool shortRead = FALSE;
 	if ( !d->decoder )
@@ -724,7 +729,9 @@ uint QTextStream::ts_getbuf( QChar* buf, uint len )
 	    if ( shortRead )
 		return rnum;
 	}
-    } else if ( latin1 ) {
+    } else
+#endif
+    if ( latin1 ) {
 	if ( len == 1+rnum ) {
 	    // use this method for one character because it is more efficient
 	    // (arnt doubts whether it makes a difference, but lets it stand)
@@ -801,12 +808,15 @@ uint QTextStream::ts_getbuf( QChar* buf, uint len )
 */
 void QTextStream::ts_putc( QChar c )
 {
+#ifndef QT_NO_TEXTCODEC
     if ( mapper ) {
 	int len = 1;
 	QString s = c;
 	QCString block = mapper->fromUnicode( s, len );
 	dev->writeBlock( block, len );
-    } else if ( latin1 ) {
+    } else
+#endif
+    if ( latin1 ) {
 	if( c.row() )
 	    dev->putch( '?' ); //######unknown character???
 	else
@@ -1558,6 +1568,9 @@ QString QTextStream::read()
 
 /*!
   Writes a \c char to the stream and returns a reference to the stream.
+
+  The character \a c is assumed to be Latin1 encoded independent of the Encoding set
+  for the QTextStream.
 */
 QTextStream &QTextStream::operator<<( QChar c )
 {
@@ -1797,6 +1810,9 @@ QTextStream &QTextStream::operator<<( double f )
 
 /*!
   Writes a string to the stream and returns a reference to the stream.
+
+  The string \a s is assumed to be Latin1 encoded independent of the Encoding set
+  for the QTextStream.
 */
 
 QTextStream &QTextStream::operator<<( const char* s )
@@ -1834,6 +1850,9 @@ QTextStream &QTextStream::operator<<( const char* s )
 
 /*!
   Writes \a s to the stream and returns a reference to the stream.
+
+  The string \a s is assumed to be Latin1 encoded independent of the Encoding set
+  for the QTextStream.
 */
 
 QTextStream &QTextStream::operator<<( const QCString & s )
@@ -2145,10 +2164,16 @@ void QTextStream::setEncoding( Encoding e )
 	internalOrder = TRUE;
 	break;
     case UnicodeUTF8:
+#ifndef QT_NO_CODECS
 	mapper = QTextCodec::codecForMib( 106 );
 	latin1 = FALSE;
 	doUnicodeHeader = TRUE;
 	internalOrder = TRUE;
+#else
+	mapper = 0;
+	latin1 = TRUE;
+	doUnicodeHeader = TRUE;
+#endif
 	break;
     case UnicodeNetworkOrder:
 	mapper = 0;
@@ -2170,12 +2195,14 @@ void QTextStream::setEncoding( Encoding e )
 	break;
     case Locale:
 	latin1 = TRUE; 				// fallback to Latin 1
+#ifndef QT_NO_TEXTCODEC
 	mapper = QTextCodec::codecForLocale();
 #if defined(_OS_WIN32_)
 	if ( GetACP() == 1252 )
 	    mapper = 0;				// Optimized latin1 processing
 #endif
 	if ( mapper && mapper->mibEnum() == 4 )
+#endif
 	    mapper = 0;				// Optimized latin1 processing
 	doUnicodeHeader = TRUE; // If it reads as Unicode, accept it
 	break;
@@ -2188,6 +2215,7 @@ void QTextStream::setEncoding( Encoding e )
 }
 
 
+#ifndef QT_NO_TEXTCODEC
 /*!  Sets the codec for this stream to \a codec. Will not try to
   autodetect Unicode.
 
@@ -2204,5 +2232,6 @@ void QTextStream::setCodec( QTextCodec *codec )
     mapper = codec;
     doUnicodeHeader = FALSE;
 }
+#endif
 
 #endif // QT_NO_TEXTSTREAM
