@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/src/widgets/qbuttongroup.cpp   2.2.1   edited 2000-08-25 $
+** $Id: qt/src/widgets/qbuttongroup.cpp   2.2.2   edited 2000-10-11 $
 **
 ** Implementation of QButtonGroup class
 **
@@ -36,7 +36,7 @@
 **********************************************************************/
 
 #include "qbuttongroup.h"
-#ifndef QT_NO_COMPLEXWIDGETS
+#ifndef QT_NO_BUTTONGROUP
 #include "qbutton.h"
 #include "qlist.h"
 #include "qradiobutton.h"
