@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/src/widgets/qhbox.cpp   2.2.1   edited 2000-08-25 $
+** $Id: qt/src/widgets/qhbox.cpp   2.2.2   edited 2000-10-11 $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -32,7 +32,7 @@
 **********************************************************************/
 
 #include "qhbox.h"
-#ifndef QT_NO_COMPLEXWIDGETS
+#ifndef QT_NO_HBOX
 #include "qlayout.h"
 #include "qapplication.h"
 #include "qobjectlist.h"
