@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/src/widgets/qlcdnumber.cpp   2.2.1   edited 2000-08-25 $
+** $Id: qt/src/widgets/qlcdnumber.cpp   2.2.2   edited 2000-11-01 $
 **
 ** Implementation of QLCDNumber class
 **
@@ -187,7 +187,7 @@ static QString double2string( double num, int base, int ndigits, bool *oflow )
 	}
 	s = int2string( (int)num, base, ndigits, 0 );
     } else {					// decimal base
-	s.sprintf( "%*g", ndigits, num );
+	s.sprintf( "%*.*g", ndigits, ndigits, num );
 	int i = s.find('e');
 	if ( i > 0 && s[i+1]=='+' ) {
 	    s[i] = ' ';
