@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/src/widgets/qprogressbar.cpp   2.2.1   edited 2000-08-25 $
+** $Id: qt/src/widgets/qprogressbar.cpp   2.2.2   edited 2000-10-19 $
 **
 ** Implementation of QProgressBar class
 **
@@ -36,7 +36,7 @@
 **********************************************************************/
 
 #include "qprogressbar.h"
-#ifndef QT_NO_COMPLEXWIDGETS
+#ifndef QT_NO_PROGRESSBAR
 #include "qpainter.h"
 #include "qdrawutil.h"
 #include "qapplication.h"
@@ -403,7 +403,12 @@ void QProgressBar::drawContents( QPainter *p )
 	    AlignRight | AlignVCenter, progress_str );
     } else {
 	if (total_steps) { // Sanity check
-	    int pw = bar.width() * progress_val / total_steps;
+	    int u = bar.width();
+	    int pw;
+	    if ( u > 0 && progress_val >= INT_MAX / u && total_steps >= u )
+		pw = (u * (progress_val / u)) / (total_steps / u);
+	    else
+		pw = bar.width() * progress_val / total_steps;
 
 	    p->setPen( colorGroup().highlightedText() );
 	    p->setClipRect( bar.x(), bar.y(), pw, bar.height() );
