@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/src/widgets/qpushbutton.cpp   2.2.1   edited 2000-09-28 $
+** $Id: qt/src/widgets/qpushbutton.cpp   2.2.2   edited 2000-11-02 $
 **
 ** Implementation of QPushButton class
 **
@@ -36,7 +36,7 @@
 **********************************************************************/
 
 #include "qpushbutton.h"
-#ifndef QT_NO_COMPLEXWIDGETS
+#ifndef QT_NO_PUSHBUTTON
 #include "qdialog.h"
 #include "qfontmetrics.h"
 #include "qpainter.h"
@@ -258,7 +258,11 @@ void QPushButton::init()
     lastEnabled = FALSE;
     hasMenuArrow = FALSE;
     flt = FALSE;
+#ifndef QT_NO_DIALOG
     autoDefButton = topLevelWidget()->inherits("QDialog");
+#else
+    autoDefButton = FALSE;
+#endif
     setBackgroundMode( PaletteButton );
     setSizePolicy( QSizePolicy( QSizePolicy::Minimum, QSizePolicy::Fixed ) );
 }
@@ -369,8 +373,10 @@ void QPushButton::setDefault( bool enable )
     if ( (bool)defButton == enable )
 	return;					// no change
     defButton = enable;
+#ifndef QT_NO_DIALOG
     if ( defButton && topLevelWidget()->inherits( "QDialog" ) )
  	((QDialog*)topLevelWidget())->setDefault( this );
+#endif
     update();
 }
 
@@ -576,10 +582,12 @@ void QPushButton::focusInEvent( QFocusEvent *e )
 {
     if ( autoDefButton )
 	setDefault( TRUE );
+#ifndef QT_NO_DIALOG
     else {
 	if ( topLevelWidget()->inherits("QDialog") )
 	    ((QDialog*)topLevelWidget())->hideDefault();
     }
+#endif
     QButton::focusInEvent( e );
 }
 
@@ -587,10 +595,12 @@ void QPushButton::focusInEvent( QFocusEvent *e )
 */
 void QPushButton::focusOutEvent( QFocusEvent *e )
 {
+#ifndef QT_NO_DIALOG
     if ( defButton && autoDefButton ) {
 	if ( topLevelWidget()->inherits("QDialog") )
 	    ((QDialog*)topLevelWidget())->setDefault( 0 );
     }
+#endif
 
     QButton::focusOutEvent( e );
 }
@@ -716,6 +726,7 @@ void QPushButton::popupPressed()
 void QPushButton::setFlat( bool f )
 {
     flt = f;
+    update();
 }
 
 /*!
