@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/src/widgets/qrangecontrol.cpp   2.2.1   edited 2000-08-25 $
+** $Id: qt/src/widgets/qrangecontrol.cpp   2.2.2   edited 2000-10-11 $
 **
 ** Implementation of QRangeControl class
 **
@@ -36,7 +36,7 @@
 **********************************************************************/
 
 #include "qrangecontrol.h"
-#ifndef QT_NO_COMPLEXWIDGETS
+#ifndef QT_NO_RANGECONTROL
 #include "qglobal.h"
 #include <limits.h>
 
