@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/src/widgets/qscrollbar.cpp   2.2.1   edited 2000-08-25 $
+** $Id: qt/src/widgets/qscrollbar.cpp   2.2.2   edited 2000-10-11 $
 **
 ** Implementation of QScrollBar class
 **
@@ -36,7 +36,7 @@
 **********************************************************************/
 
 #include "qscrollbar.h"
-#ifndef QT_NO_COMPLEXWIDGETS
+#ifndef QT_NO_SCROLLBAR
 #include "qpainter.h"
 #include "qbitmap.h"
 #include "qapplication.h"
