@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/src/widgets/qsplitter.cpp   2.2.1   edited 2000-08-27 $
+** $Id: qt/src/widgets/qsplitter.cpp   2.2.2   edited 2000-10-11 $
 **
 **  Splitter widget
 **
@@ -35,7 +35,7 @@
 **
 **********************************************************************/
 #include "qsplitter.h"
-#ifndef QT_NO_COMPLEXWIDGETS
+#ifndef QT_NO_SPLITTER
 
 #include "qpainter.h"
 #include "qdrawutil.h"
