@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/src/widgets/qstatusbar.cpp   2.2.1   edited 2000-08-25 $
+** $Id: qt/src/widgets/qstatusbar.cpp   2.2.2   edited 2000-10-11 $
 **
 ** Implementation of QStatusBar class
 **
@@ -36,7 +36,7 @@
 **********************************************************************/
 
 #include "qstatusbar.h"
-#ifndef QT_NO_COMPLEXWIDGETS
+#ifndef QT_NO_STATUSBAR
 
 #include "qlist.h"
 #include "qlayout.h"
