@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/src/widgets/qstatusbar.h   2.2.1   edited 2000-08-25 $
+** $Id: qt/src/widgets/qstatusbar.h   2.2.2   edited 2000-10-11 $
 **
 ** Definition of QStatusBar class
 **
@@ -42,7 +42,7 @@
 #include "qwidget.h"
 #endif // QT_H
 
-#ifndef QT_NO_COMPLEXWIDGETS
+#ifndef QT_NO_STATUSBAR
 
 
 class QStatusBarPrivate;
@@ -84,6 +84,6 @@ private:	// Disabled copy constructor and operator=
 #endif
 };
 
-#endif // QT_NO_COMPLEXWIDGETS
+#endif // QT_NO_STATUSBAR
 
 #endif // QSTATUSBAR_H
