@@ -488,7 +488,7 @@ void FormWindow::handleMousePress( QMouseEvent *e, QWidget *w )
 	} else { // press was on the formwindow
 	    if ( e->button() == LeftButton ) { // left button: start rubber selection and show formwindow properties
 		drawRubber = TRUE;
-		if ( !( ( e->state() && ControlButton ) || ( e->state() & ShiftButton ) ) ) {
+		if ( !( ( e->state() & ControlButton ) || ( e->state() & ShiftButton ) ) ) {
 		    clearSelection( FALSE );
 		    QWidget *opw = propertyWidget;
 		    propertyWidget = mainContainer();
@@ -739,8 +739,19 @@ void FormWindow::handleMouseRelease( QMouseEvent *e, QWidget *w )
 		}
 		
 		// doesn't need to be a command, the MoveCommand does reparenting too
+		bool emitSelChanged = FALSE;
 		for ( QMap<ulong, QPoint>::Iterator it = moving.begin(); it != moving.end(); ++it ) {
 		    QWidget *i = (QWidget*)it.key();
+		    if ( !emitSelChanged && i->inherits( "QButton" )  ) {
+			if ( i->parentWidget() && i->parentWidget()->inherits( "QButtonGroup" ) ||
+			     wa->inherits( "QButtonGroup" ) )
+			    emitSelChanged = TRUE;
+			if ( !wa->inherits( "QButtonGroup" ) ) {
+			    MetaDataBase::setPropertyChanged( i, "buttonGroupId", FALSE );
+			    if ( i->parentWidget() && i->parentWidget()->inherits( "QButtonGroup" ) )
+				( (QButtonGroup*)i->parentWidget() )->remove( (QButton*)i );
+			}
+		    }
 		    QPoint pos = wa->mapFromGlobal( i->mapToGlobal( QPoint(0,0) ) );
 		    i->reparent( wa, pos, TRUE );
 		    raiseSelection( i );
@@ -749,6 +760,10 @@ void FormWindow::handleMouseRelease( QMouseEvent *e, QWidget *w )
 		    mainWindow()->objectHierarchy()->widgetRemoved( i );
 		    mainWindow()->objectHierarchy()->widgetInserted( i );
 		}
+		if ( emitSelChanged ) {
+		    emit showProperties( wa );
+		    emit showProperties( propertyWidget );
+		}
 		newParent = wa;
 	    }
 	
